pub trait MallocShallowSizeOf {
// Required method
fn shallow_size_of(&self, ops: &mut MallocSizeOfOps) -> usize;
}Expand description
Trait for measuring the “shallow” heap usage of a container.
Required Methods
Sourcefn shallow_size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn shallow_size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of immediate heap-allocated descendant structures, but not the space taken up by the value itself. Anything beyond the immediate descendants must be measured separately, using iteration.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".